==> mediawiki-1.12.1.tar.gz: mediawiki-1.12.1/languages/messages/MessagesAy.php <==
<?php
/** Aymara (Aymar)
 *
 * @ingroup Language
 * @file
 *
 * @author Kanon6917
 */

$fallback = 'es';

$messages = array(
'article'    => 'Amtachinu',
'cancel'     => 'Jan saña',
'qbfind'     => 'Thaqaña',
'qbedit'     => 'Trukaña',
'navigation' => 'Wampuña',

'errorpagetitle'   => 'Pantja',
'help'             => 'Yanapaña',
'search'           => 'Thaqaña',
'searchbutton'     => 'Thaqaña',
'go'               => 'Saraña',
'searcharticle'    => 'Saraña',
'history'          => 'Nayra qillqata',
'history_short'    => 'Nayra qillqata',
'edit'             => 'Trukaña',
'delete'           => 'Pichaña',
'talkpagelinktext' => 'Kutkatasiña',
'talk'             => 'Tuqisiwi',
'otherlanguages'   => 'Yaqha arunaka',
'jumptonavigation' => 'wampuña',
'jumptosearch'     => 'thaqaña',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'     => 'Jichha pacha',
'currentevents-url' => 'Project:Jichha pacha',
'mainpage'          => 'Nayriri Uñstawi',
'portal'            => 'Jayma punku',
'portal-url'        => 'Project:Jayma punku',
'sitesupport'       => 'Ramañanaka',

'editsection' => 'trukaña',
'editold'     => 'trukaña',
'showtoc'     => 'uñachayaña',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Amtachinu',
'nstab-user'     => 'Apnaqiri',
'nstab-help'     => 'Yanapaña',
'nstab-category' => 'Patawi',

# General errors
'error' => 'Pantja',

# Login and logout pages
'loginpagetitle'     => "Qillqt'ayasiña/Entrar",
'login'              => "Qillqt'ayasiña/Entrar",
'userlogin'          => "Qillqt'ayasiña/Entrar",
'logout'             => 'Mistuña',
'userlogout'         => 'Mistuña',
'yourlanguage'       => 'Aru:',
'email'              => "Aru jalayiri (''E-mail'')",
'loginlanguagelabel' => 'Aru: $1',

# Edit pages
'summary'  => 'Juk’aptayawi',
'subject'  => 'Yatsuwi/titulu',
'yourdiff' => 'Jalaqtatanaka',

# Preferences page
'prefs-rc'       => 'Jichha kutikiptatanaka',
'timezoneoffset' => 'Jalaqtata',

# Recent changes
'recentchanges' => 'Jichha kutikiptatanaka',
'show'          => 'uñachayaña',

# Upload
'fileuploadsummary' => 'Uñt’ayawi:',

'license' => 'Iyawsawi:',

# Image list
'filehist-user'         => 'Apnaqiri',
'imagelist_date'        => 'Uru jakhu',
'imagelist_user'        => 'Apnaqiri',
'imagelist_description' => 'Uñt’ayawi',

# Miscellaneous special pages
'move' => 'Qillqaraña',

# Special:Log
'specialloguserlabel'  => 'Apnaqiri:',
'speciallogtitlelabel' => 'Titulu:',
'log-search-submit'    => 'Saraña',

# Special:Listusers
'listusers-submit' => 'Uñachayaña',

# Watchlist
'watch' => 'Uñjaña',

# Restrictions (nouns)
'restriction-move' => 'Qillqaraña',

# Undelete
'undelete-search-submit' => 'Thaqaña',

'sp-contributions-submit' => 'Thaqaña',

# Block/unblock
'ipblocklist-submit' => 'Thaqaña',
'proxyblocksuccess'  => 'Kamachawi',

# Tooltip help for the actions
'tooltip-p-logo' => 'Nayriri Uñstawi',

# Attribution
'others' => 'yaqha',

# action=purge
'confirm_purge_button' => 'Iyaw saña',

# Multipage image navigation
'imgmultigo' => '¡Saraña!',

# Table pager
'table_pager_limit_submit' => 'Saraña',

);

==> mediawiki-1.13.0rc2.tar.gz: mediawiki-1.13.0rc2/languages/messages/MessagesAy.php <==
<?php
/** Aymara (Aymar)
 *
 * @ingroup Language
 * @file
 *
 * @author Kanon6917
 * @author Siebrand
 */

$fallback = 'es';

$messages = array(
'article'    => 'Amtachinu',
'cancel'     => 'Jan saña',
'qbfind'     => 'Thaqaña',
'qbedit'     => 'Trukaña',
'navigation' => 'Wampuña',

'errorpagetitle'   => 'Pantja',
'help'             => 'Yanapaña',
'search'           => 'Thaqaña',
'searchbutton'     => 'Thaqaña',
'go'               => 'Saraña',
'searcharticle'    => 'Saraña',
'history'          => 'Nayra qillqata',
'history_short'    => 'Nayra qillqata',
'edit'             => 'Trukaña',
'delete'           => 'Pichaña',
'talkpagelinktext' => 'Kutkatasiña',
'talk'             => 'Tuqisiwi',
'otherlanguages'   => 'Yaqha arunaka',
'jumptonavigation' => 'wampuña',
'jumptosearch'     => 'thaqaña',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Jichha pacha',
'currentevents-url'    => 'Project:Jichha pacha',
'mainpage'             => 'Nayriri Uñstawi',
'mainpage-description' => 'Nayriri Uñstawi',
'portal'               => 'Jayma punku',
'portal-url'           => 'Project:Jayma punku',

'editsection' => 'trukaña',
'editold'     => 'trukaña',
'showtoc'     => 'uñachayaña',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Amtachinu',
'nstab-user'     => 'Apnaqiri',
'nstab-help'     => 'Yanapaña',
'nstab-category' => 'Patawi',

# General errors
'error' => 'Pantja',

# Login and logout pages
'loginpagetitle'     => "Qillqt'ayasiña/Entrar",
'login'              => "Qillqt'ayasiña/Entrar",
'userlogin'          => "Qillqt'ayasiña/Entrar",
'logout'             => 'Mistuña',
'userlogout'         => 'Mistuña',
'yourlanguage'       => 'Aru:',
'email'              => "Aru jalayiri (''E-mail'')",
'loginlanguagelabel' => 'Aru: $1',

# Edit pages
'summary'  => 'Juk’aptayawi',
'subject'  => 'Yatsuwi/titulu',
'yourdiff' => 'Jalaqtatanaka',

# Preferences page
'prefs-rc'       => 'Jichha kutikiptatanaka',
'timezoneoffset' => 'Jalaqtata',

# Recent changes
'recentchanges' => 'Jichha kutikiptatanaka',
'show'          => 'uñachayaña',

# Upload
'fileuploadsummary' => 'Uñt’ayawi:',

'license' => 'Iyawsawi:',

# Special:ImageList
'imagelist_date'        => 'Uru jakhu',
'imagelist_user'        => 'Apnaqiri',
'imagelist_description' => 'Uñt’ayawi',

# Image description page
'filehist-user' => 'Apnaqiri',

# Miscellaneous special pages
'move' => 'Qillqaraña',

# Special:Log
'specialloguserlabel'  => 'Apnaqiri:',
'speciallogtitlelabel' => 'Titulu:',
'log-search-submit'    => 'Saraña',

# Special:ListUsers
'listusers-submit' => 'Uñachayaña',

# Watchlist
'watch' => 'Uñjaña',

# Restrictions (nouns)
'restriction-move' => 'Qillqaraña',

# Undelete
'undelete-search-submit' => 'Thaqaña',

'sp-contributions-submit' => 'Thaqaña',

# Block/unblock
'ipblocklist-submit' => 'Thaqaña',
'proxyblocksuccess'  => 'Kamachawi',

# Tooltip help for the actions
'tooltip-p-logo' => 'Nayriri Uñstawi',

# Attribution
'others' => 'yaqha',

# action=purge
'confirm_purge_button' => 'Iyaw saña',

# Multipage image navigation
'imgmultigo' => '¡Saraña!',

# Table pager
'table_pager_limit_submit' => 'Saraña',

);
